import * as React from 'react';
import { NsInputField } from '../input';
import { Autocomplete, AutocompleteRenderGroupParams, List, AutocompleteRenderInputParams } from '@mui/material';
import { useState, PropsWithChildren, useRef } from 'react';
import { NsTypography } from '../typography';
import { NsAutocompleteProps, OptionsProps, ComponentboxProps } from './types.d';
import { NsButton } from '../button';

const NsAutocomplete = ({
    id = 'custom_autocomplete_dropdown',
    options = [],
    renderOptions,
    onSelect,
    clear,
    seeMore,
    placeholder,
    className,
}: PropsWithChildren<NsAutocompleteProps>) => {
    const inputRef = useRef(null);

    const [selectedOption, setSelectedOption] = useState<OptionsProps | null>(null);
    const OptionUI = renderOptions;

    const handleSelect = (event: React.SyntheticEvent<Element, Event>, value: OptionsProps | null) => {
        setSelectedOption(value);
        onSelect ? onSelect(value) : null;
    };

    const renderInput = (params: AutocompleteRenderInputParams) => (
        <NsInputField {...params} placeholder={placeholder} inputRef={inputRef} />
    );

    const renderOption = (props: ComponentboxProps, option: OptionsProps) => (
        <li {...props}>
            <OptionUI {...props} option={option} />
        </li>
    );

    const renderOptionLabel = (option: OptionsProps) => option.value;

    const renderGroupBy = (option: OptionsProps) => option.group as string;

    const renderGroupName = ({ key, group, children }: AutocompleteRenderGroupParams) => (
        <li key={key}>
            {group ? (
                <NsTypography variant="p-s" className="p-3">
                    {group}
                </NsTypography>
            ) : null}
            <span>{children}</span>
        </li>
    );

    const renderClearButton = () => {
        const { show, onClear, text = 'See More Results' } = clear || {};
        if (!show) {
            return null;
        }
        return (
            <div className="text-right p-3">
                <NsButton onClick={onClear} data-testid="autocomplete-clear-id">
                    <NsTypography variant={'p-xs'}>{text}</NsTypography>
                </NsButton>
            </div>
        );
    };

    const renderSeeMoreButton = () => {
        const { show, onSeeMore, text = 'See More Results' } = seeMore || {};
        if (!show) {
            return null;
        }
        return (
            <div className="text-center p-3">
                <NsButton onClick={onSeeMore} data-testid="autocomplete-loadmore-id">
                    <NsTypography variant="p-xs">{text}</NsTypography>
                </NsButton>
            </div>
        );
    };

    const renderListBoxComponent = ({ children, ...otherProps }: ComponentboxProps) => (
        <>
            {renderClearButton()}
            <List {...otherProps}>
                {children}
                {renderSeeMoreButton()}
            </List>
        </>
    );

    return (
        <Autocomplete
            id={id}
            disablePortal
            className={className}
            options={options}
            groupBy={renderGroupBy}
            getOptionLabel={renderOptionLabel}
            renderOption={renderOption}
            renderInput={renderInput}
            ListboxComponent={renderListBoxComponent}
            renderGroup={renderGroupName}
            onChange={handleSelect}
            value={selectedOption}
        />
    );
};

export default NsAutocomplete;
