import React, { useMemo } from 'react';
import Slider from 'react-slick';
import { NsScrollingCarousalProps } from '../';

const NsScrollingCarousal = ({
    slides,
    scrollSeconds,
    stillSeconds,
    renderSlide,
    settings,
    additionalProps,
}: NsScrollingCarousalProps) => {
    const defaultSettings = useMemo(() => {
        return {
            ...settings,
            autoplay: true,
            autoplaySpeed: stillSeconds * 1000 || 2000, // autoplaySpeed = delay between scroll in milliseconds
            accessibility: true,
            adaptiveHeight: true,
            arrows: true,
            draggable: true,
            dots: true,
            infinite: true,
            speed: scrollSeconds * 1000 || 500, // speed = animation speed in milliseconds
            slidesToShow: 1,
            slidesToScroll: 1,
            swipeToSlide: true,
        };
    }, [stillSeconds, scrollSeconds, settings]);
    return (
        <div data-testid={additionalProps?.testid ?? 'scrolling-carousal-test-id'}>
            <Slider {...defaultSettings}>{slides.map(renderSlide)}</Slider>
        </div>
    );
};

export default NsScrollingCarousal;
