import { PropsWithChildren, useMemo } from 'react';
import { getColumnSizes } from './utils';
import { StyledFlex } from './styled/StyledFlex';
import { AdditionalProps } from '../common.types';

type NsFlexColumnsProps = PropsWithChildren<{
    columnClass: string;
    gap: number;
}> &
    AdditionalProps;

const NsFlexColumns = ({ columnClass, children, gap, additionalProps }: NsFlexColumnsProps) => {
    const sizes = useMemo(() => {
        return getColumnSizes(columnClass ?? 'ns-col-lg-1-1');
    }, [columnClass]);
    return (
        <StyledFlex
            gap={gap}
            sizes={sizes}
            className="styled-flex"
            data-testid={additionalProps?.testid ?? 'ns-flex-columns'}
        >
            {children}
        </StyledFlex>
    );
};
export default NsFlexColumns;
