import { Box } from '@mui/material';
import { styled } from '@nuskin/foundation-theme';
import { sizeObjectType } from '../types';
import { commonStyles, getPercentArray } from './common';

const options = {
    shouldForwardProp: (propKey: string) => propKey !== 'sizes | gap',
};

type StyledFlexProps = {
    sizes: sizeObjectType;
    gap?: number;
};

/* main wrapper for column control using css flex */
export const StyledFlex = styled(
    Box as any,
    options
)<StyledFlexProps>(({ sizes, gap }: StyledFlexProps) => {
    const gridGap = gap ? `${gap}px` : '2rem';
    const fraction = getPercentArray(sizes.fractions);
    const flexResponsive = { flexGrow: 1, flexShrink: 1 };
    const style: any = {
        gap: gridGap,
        ...commonStyles,
        display: 'flex',
        paddingInline: '20px',
        flexWrap: 'wrap',
        justifyContent: 'center',
        ' > *': {
            display: 'flex',
        },
    };
    fraction.forEach((f, i) => {
        style[`> :nth-of-type(${fraction.length}n+${i + 1})`] = {
            flexBasis: `calc(${fraction[i]} - ${gridGap})`,
            ...flexResponsive,
        };
    });
    return style;
});
