import { Box } from '@mui/material';
import { styled } from '@nuskin/foundation-theme';
import { sizeObjectType } from '../types';
import { commonStyles, getPercentArray } from './common';

type StyledGridProps = {
    sizes: sizeObjectType;
    gap?: number;
};
const options = {
    shouldForwardProp: (propKey: string) => propKey !== 'sizes | gap',
};

/* main wrapper for column control using css grid */
export const StyledGrid = styled(
    Box as any,
    options
)<StyledGridProps>(({ sizes, gap }: StyledGridProps) => {
    const gridGap = gap ?? '2rem';
    return {
        gap: gridGap,
        ...commonStyles,
        display: 'grid',
        /* here we are creating gridTemplateColumns as calc(40% - 20px) calc(40% - 20px), */
        gridTemplateColumns: getPercentArray(sizes.fractions)
            ?.map((fractionPercent) => `calc(${fractionPercent} - 20px)`)
            .join(''),
        justifyContent: 'center',
        '.span-2': {
            gridColumn: 'span 2',
        },
    } as any;
});
