import React from 'react';
import { render, fireEvent, screen } from '@/test-utils/index';
import NsTable from './NsTable';

describe('NsTable', () => {
    const headers = [
        { id: 'name', label: 'Name', numeric: false },
        { id: 'age', label: 'Age', numeric: true },
    ];

    const items = [
        { name: 'John', age: 26 },
        { name: 'Jane', age: 32 },
        { name: 'Maria', age: 28 },
        { name: 'Kevin', age: 31 },
        { name: 'Suzan', age: 25 },
        { name: 'Dan', age: 30 },
        { name: 'Micheal', age: 39 },
        { name: 'Sandy', age: 39 },
    ];

    const rows = 5;
    const isShowSelector = true;
    const rowsPerPageOptions = [5, 10, 15];
    const itemKey = 'name';

    it('renders table with correct data', () => {
        render(
            <NsTable
                headers={headers}
                items={items}
                rows={rows}
                isShowSelector={isShowSelector}
                rowsPerPageOptions={rowsPerPageOptions}
                itemKey={itemKey}
                isPagination
            />
        );

        expect(screen.getByText('Name')).toBeInTheDocument();
        expect(screen.getByText('Age')).toBeInTheDocument();
        expect(screen.getByText('Kevin')).toBeInTheDocument();
        expect(screen.getByText('Maria')).toBeInTheDocument();
        expect(screen.getByText('28')).toBeInTheDocument();
        expect(screen.getByText('31')).toBeInTheDocument();
        expect(screen.getByRole('button', { name: 'Rows per page: 5' })).toBeInTheDocument();
    });

    it('selects and deselects rows on click', () => {
        render(
            <NsTable
                headers={headers}
                items={items}
                rows={rows}
                isShowSelector={isShowSelector}
                rowsPerPageOptions={rowsPerPageOptions}
                itemKey={itemKey}
                isPagination
            />
        );

        expect(screen.getByText('Kevin')).toBeInTheDocument();
        const button = screen.getByText('Kevin');
        fireEvent.click(button);

        expect(screen.getByTestId('table-row-3')).toHaveAttribute('aria-checked', 'true');
        fireEvent.click(button);
        expect(screen.getByTestId('table-row-3')).toHaveAttribute('aria-checked', 'false');
    });

    it('hide selectors', () => {
        render(
            <NsTable
                headers={headers}
                items={items}
                rows={rows}
                isShowSelector={!isShowSelector}
                rowsPerPageOptions={rowsPerPageOptions}
                itemKey={itemKey}
                isPagination
            />
        );
    });

    it('selects all rows', () => {
        render(
            <NsTable
                headers={headers}
                items={items}
                rows={rows}
                isShowSelector={isShowSelector}
                rowsPerPageOptions={rowsPerPageOptions}
                itemKey={itemKey}
                isPagination
            />
        );

        expect(screen.getByTestId('header-checkbox')).toBeInTheDocument();

        const button = screen.getByTestId('header-checkbox');

        fireEvent.click(button);
        expect(screen.getByTestId('table-checkbox-0')).toHaveClass('PrivateSwitchBase-input');
    });

    it('selects all rows when click all values', async () => {
        render(
            <NsTable
                headers={headers}
                items={items}
                rows={rows}
                isShowSelector={isShowSelector}
                rowsPerPageOptions={rowsPerPageOptions}
                itemKey={itemKey}
                isPagination
            />
        );

        expect(screen.getByTestId('KeyboardArrowRightIcon')).toBeInTheDocument();

        const button = screen.getByTestId('KeyboardArrowRightIcon');
        fireEvent.click(button);
        expect(screen.getByText('Sandy')).toBeInTheDocument();
    });

    it('sort rows via age', () => {
        render(
            <NsTable
                headers={headers}
                items={items}
                rows={rows}
                isShowSelector={isShowSelector}
                rowsPerPageOptions={rowsPerPageOptions}
                itemKey={itemKey}
                isPagination
            />
        );

        expect(screen.getByText('Age')).toBeInTheDocument();
        const button = screen.getByText('Age');
        fireEvent.click(button);

        expect(screen.getByText('John')).toBeInTheDocument();
        fireEvent.click(button);
    });
});
