import type { NsTableHeaderProps, Item } from './types.d';
import React from 'react';
import { TableHead, TableRow, Box, TableCell } from '@mui/material';
import { StyledTableSortLabel } from './NsTable.styled';
import { visuallyHidden } from '@mui/utils';
import NsCheckBox from '../checkbox/NsCheckbox';

export default function NsTableHeader(props: NsTableHeaderProps) {
    const { order, orderBy, numSelected, rowCount, headCells, isShowSelector, onRequestSort, onSelectAllClick } = props;
    const createSortHandler = (property: keyof Item) => (event: React.MouseEvent<unknown>) => {
        onRequestSort(event, property);
    };

    return (
        <TableHead>
            <TableRow>
                {isShowSelector ? (
                    <TableCell padding="checkbox">
                        <NsCheckBox
                            checked={rowCount > 0 && numSelected > 0}
                            onChange={onSelectAllClick}
                            testid="header-checkbox"
                            name="header-checkbox"
                            label=""
                            className="ml-0 !important"
                        />
                    </TableCell>
                ) : null}
                {headCells.map((headCell) => (
                    <TableCell key={headCell.id} sortDirection={orderBy == headCell.id ? order : false}>
                        <StyledTableSortLabel
                            active={orderBy == headCell.id}
                            direction={orderBy == headCell.id ? order : 'asc'}
                            onClick={createSortHandler(headCell.id)}
                        >
                            {headCell.label}
                            {orderBy === headCell.id ? (
                                <Box component="span" sx={visuallyHidden}>
                                    {order === 'desc' ? 'sorted descending' : 'sorted ascending'}
                                </Box>
                            ) : null}
                        </StyledTableSortLabel>
                    </TableCell>
                ))}
            </TableRow>
        </TableHead>
    );
}
